<?php
    /* 
    ============================================================================
    main entry point for normal users. this page decides whether to fetch the
    data from the database or to display the contents of a prerendered file.
    ============================================================================
    Author: Martin Widmann, martin.widmann@ideefix.net
    Version: 1.2
    */

    require("config.php");
    require("db_functions.php");
    require("file_functions.php");

    $id = $_REQUEST["id"];
    
    if ($id == '') {
        // try to find out what the oldest enabled match is. I decided it to be
        // the oldest as some of the users tend to create many games in advance
        // and choosing the newest would most probably create wrong output.
        $sql = "SELECT min(match_id) AS rid FROM liveticker_match WHERE running = 1";
        if ($conn->query($sql) > 0) {
            $row = $conn->resultRows[0];
            $rid = $row->rid;
            if ($rid != NULL) {
                header("Location: index.php?id=" . $rid);
                exit();
            } else {
            
            	// try to find out the newest disabled match. This could be tricky if there are
            	// matches in the future that are disabled, but should work.
            	$sql = "SELECT max(match_id) AS mid FROM liveticker_match WHERE running = 0";
            	if ($conn->query($sql) > 0) {
            		$row = $conn->resultRows[0];
            		$mid = $row->mid;
            		if ($mid != NULL) {
    		            header("Location: index.php?id=" . $mid);
	        	        exit();
            		} else {
			            echo("Can't determine a match. Guess there are no.");
    	    		    exit();
            		}
            	} else {
		            echo("Can't determine a match. Guess there are no.");
        		    exit();
            	}
                echo("Sorry pal, there are no running matches right now. You'll need a specific ID to access them.");
                exit();
            }
        } else {
            echo("Can't determine a currently running match. You'll need a specific ID to access them.");
            exit();
        }
    }
    
    $updateFile = OUTPUTDIR . "/update_$id";
    $tickerFile = OUTPUTDIR . "/ticker_$id";
    
    $content = "";
    // look for the existance of a file called update_$id. if there is none just
    // load all the info from the ticker_$id fragment and display what's in there.
    // if there have been no changes there's no need to load all the stuff every
    // time
    if (file_exists($updateFile)) {
        
        // delete the update file as only one process should recreate the data
        unlink($updateFile);
        
        // loading the fragments into memory.
        $matchFragment = loadContent(FRAGMENTDIR . '/match.html');
        $infoFragment = loadContent(FRAGMENTDIR . '/info.html');
        $goalFragment = loadContent(FRAGMENTDIR . '/goal.html');
        $penaltyFragment = loadContent(FRAGMENTDIR . '/penalty.html');
        $bodyFragment = loadContent(FRAGMENTDIR . '/body.html');
        $goalStatsFragment = loadContent(FRAGMENTDIR . '/goal_stats.html');
        $penaltyStatsFragment = loadContent(FRAGMENTDIR . '/penalty_stats.html');
        $playerLinkFragment = loadContent(FRAGMENTDIR . '/player_link.html');
        $playerFragment = loadContent(FRAGMENTDIR . '/player.html');
        $metaRefresh = loadContent(FRAGMENTDIR . '/meta_refresh.html');

        $players = loadContent(OUTPUTDIR . "/players_home_" . $id);
        $players .= "\n" . loadContent(OUTPUTDIR . "/players_away_" . $id);
        $playerslist = preg_split('/[\n\r]+/', $players);
        
        // loading the data for the match itself
        $sql = "SELECT * FROM liveticker_match WHERE match_id = $id";
        
        if ($conn->query($sql) > 0) {
            
            $row = $conn->resultRows[0];
            $home           = $row->home;
            $home_name      = $row->home_name;
            $away           = $row->away;
            $away_name      = $row->away_name;
            $matchdate      = $row->matchdate;
            $info           = $conn->escape($row->info);
            $running        = $row->running;
            
            $playtime           = "00:00";
            $homegoal           = 0;
            $home_goal_p1       = 0;
            $home_goal_p2       = 0;
            $home_goal_p3       = 0;
            $home_goal_ot       = 0;
            
            $homepenalty        = 0;
            $home_penalty_p1    = 0;
            $home_penalty_p2    = 0;
            $home_penalty_p3    = 0;
            $home_penalty_ot    = 0;
            
            $awaygoal           = 0;
            $away_goal_p1       = 0;
            $away_goal_p2       = 0;
            $away_goal_p3       = 0;
            $away_goal_ot       = 0;

            $awaypenalty        = 0;
            $away_penalty_p1    = 0;
            $away_penalty_p2    = 0;
            $away_penalty_p3    = 0;
            $away_penalty_ot    = 0;
                        
            $tickerContent = "";
            
            $sql = "SELECT *, UNIX_TIMESTAMP(entry_time) AS u_entry_time FROM liveticker_entry WHERE match_id = $id ORDER BY playtime asc, entry_id asc";
            if ($conn->query($sql) > 0) {
                
                for ($i = 0; $i < $conn->resultCount; $i++) {
                    $row = $conn->resultRows[$i];
                    
                    $entry_type         = $row->entry_type;
                    $team               = $row->team;
                    $playtime           = $row->playtime;
                    $player1            = preparePlayer($row->player1, $playerslist, $playerFragment, $playerLinkFragment);
                    $player2            = preparePlayer($row->player2, $playerslist, $playerFragment, $playerLinkFragment);
                    $player3            = preparePlayer($row->player3, $playerslist, $playerFragment, $playerLinkFragment);
                    $powerplay          = $row->powerplay;
                    $penalty_time       = $row->penalty_time;
                    $penalty_reason     = $row->penalty_reason;
                    $penalty_extension  = $row->penalty_extension;
                    $info               = $conn->unescape($row->info);
                    $entry_time         = $row->u_entry_time;
                    
                    $info = preg_replace('@http://(([^\s0-9-\.][a-zA-Z0-9-\.]+)\S+)@','<a href="http://\\1" target="_blank">http://\\1</a>',$info);
                    
                    $entryValues = array(
                        'playtime' => $playtime,
                        'player1' => $player1,
                        'player2' => $player2,
                        'player3' => $player3,
                        'powerplay' => $powerplay,
                        'penalty_time' => $penalty_time,
                        'penalty_reason' => $penalty_reason,
                        'penalty_extension' => $penalty_extension,
                        'info' => eregi_replace("\n", "<br>", $info),
                        'entry_time' => date('H:i', $entry_time)
                    );

                    $teamname = "";
                    if ($team == 0) $teamname = $home_name;
                    if ($team == 1) $teamname = $away_name;
                    
                    if ($entry_type == 0) { // info
                        $entryValues = array(
                            'playtime' => $playtime,
                            'team' => $teamname,
                            'result' => $homegoal . ":" . $awaygoal,
                            'info' => eregi_replace("\n", "<br>", $info),
                            'entry_time' => date('H:i', $entry_time)
                        );
                        
                        $tickercontent = replaceFragmentPlaceholders($infoFragment, $entryValues) . $tickercontent;
                    
                    } else if ($entry_type == 1) { // goal
                        
                        if ($team == 0) {
                            $homegoal++;
                            
                            switch (getPeriod($playtime)) {
                                case 1: $home_goal_p1++;break;
                                case 2: $home_goal_p2++;break;
                                case 3: $home_goal_p3++;break;
                                case 4: $home_goal_ot++;break;
                            }                            
                            
                        } else if ($team == 1) {
                            $awaygoal++;
                            
                            switch (getPeriod($playtime)) {
                                case 1: $away_goal_p1++;break;
                                case 2: $away_goal_p2++;break;
                                case 3: $away_goal_p3++;break;
                                case 4: $away_goal_ot++;break;
                            }                            
                            
                        }
                        
                        $assist = "";
                        if ($player2 != '') {
                            $assist = "($player2";
                            if ($player3 != '') {
                                $assist .= ", $player3";
                            }
                            $assist .= ")";
                        }

                        switch ($powerplay) {
                            case 0: $pp_value = "EQ"; break;
                            case 1: $pp_value = "PP1"; break;
                            case 2: $pp_value = "PP2"; break;
                            case 3: $pp_value = "SH1"; break;
                            case 4: $pp_value = "SH2"; break;
                        }

                        if ($info != '') $info = "<br><br>$info";
                        
                        $entryValues = array(
                            'playtime' => $playtime,
                            'result' => $homegoal . ":" . $awaygoal,
                            'team' => $teamname,
                            'player1' => $player1,
                            'assists' => $assist,
                            'powerplay' => $pp_value,
                            'info' => eregi_replace("\n", "<br>", $info),
                            'entry_time' => date('H:i', $entry_time)
                        );

                        $tickercontent = replaceFragmentPlaceholders($goalFragment, $entryValues) . $tickercontent;
                    
                    } else if ($entry_type == 2) { // penalty
                        
                        if ($team == 0) {
                            if ($penalty_time == 0) {
                                $penalty = "";
                                switch ($penalty_extension) {
                                    case 0:
                                        $penalty .= ' Minuten';
                                        break;
                                    case 1:
                                        $penalty .= '2 Minuten';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 2;break;
                                            case 2: $home_penalty_p2 += 2;break;
                                            case 3: $home_penalty_p3 += 2;break;
                                            case 4: $home_penalty_ot += 2;break;
                                        }
                                        break;
                                    case 2:
                                        $penalty .= '10 Minuten Disziplinarstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 10;break;
                                            case 2: $home_penalty_p2 += 10;break;
                                            case 3: $home_penalty_p3 += 10;break;
                                            case 4: $home_penalty_ot += 10;break;
                                        }
                                        break;
                                    case 3:
                                        $penalty .= 'Spieldauerstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 20;break;
                                            case 2: $home_penalty_p2 += 20;break;
                                            case 3: $home_penalty_p3 += 20;break;
                                            case 4: $home_penalty_ot += 20;break;
                                        }
                                        break;
                                    case 4:
                                        $penalty .= 'Matchstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 25;break;
                                            case 2: $home_penalty_p2 += 25;break;
                                            case 3: $home_penalty_p3 += 25;break;
                                            case 4: $home_penalty_ot += 25;break;
                                        }
                                        break;
                                }
                            } else {
                                $penalty = $penalty_time;
                                switch (getPeriod($playtime)) {
                                    case 1: $home_penalty_p1 += $penalty_time;break;
                                    case 2: $home_penalty_p2 += $penalty_time;break;
                                    case 3: $home_penalty_p3 += $penalty_time;break;
                                    case 4: $home_penalty_ot += $penalty_time;break;
                                }
                                switch ($penalty_extension) {
                                    case 0:
                                        $penalty .= ' Minuten';
                                        break;
                                    case 1:
                                        $penalty .= '+2 Minuten';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 2;break;
                                            case 2: $home_penalty_p2 += 2;break;
                                            case 3: $home_penalty_p3 += 2;break;
                                            case 4: $home_penalty_ot += 2;break;
                                        }
                                        break;
                                    case 2:
                                        $penalty .= '+10 Minuten Disziplinarstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 10;break;
                                            case 2: $home_penalty_p2 += 10;break;
                                            case 3: $home_penalty_p3 += 10;break;
                                            case 4: $home_penalty_ot += 10;break;
                                        }
                                        break;
                                    case 3:
                                        $penalty .= ' + Spieldauerstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 20;break;
                                            case 2: $home_penalty_p2 += 20;break;
                                            case 3: $home_penalty_p3 += 20;break;
                                            case 4: $home_penalty_ot += 20;break;
                                        }
                                        break;
                                    case 4:
                                        $penalty .= ' + Matchstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $home_penalty_p1 += 25;break;
                                            case 2: $home_penalty_p2 += 25;break;
                                            case 3: $home_penalty_p3 += 25;break;
                                            case 4: $home_penalty_ot += 25;break;
                                        }
                                        break;
                                }
                            }
                        } else if ($team == 1) {
                            if ($penalty_time == 0) {
                                $penalty = "";
                                switch ($penalty_extension) {
                                    case 0:
                                        $penalty .= ' Minuten';
                                        break;
                                    case 1:
                                        $penalty .= '2 Minuten';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 2;break;
                                            case 2: $away_penalty_p2 += 2;break;
                                            case 3: $away_penalty_p3 += 2;break;
                                            case 4: $away_penalty_ot += 2;break;
                                        }
                                        break;
                                    case 2:
                                        $penalty .= '10 Minuten Disziplinarstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 10;break;
                                            case 2: $away_penalty_p2 += 10;break;
                                            case 3: $away_penalty_p3 += 10;break;
                                            case 4: $away_penalty_ot += 10;break;
                                        }
                                        break;
                                    case 3:
                                        $penalty .= 'Spieldauerstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 20;break;
                                            case 2: $away_penalty_p2 += 20;break;
                                            case 3: $away_penalty_p3 += 20;break;
                                            case 4: $away_penalty_ot += 20;break;
                                        }
                                        break;
                                    case 4:
                                        $penalty .= 'Matchstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 25;break;
                                            case 2: $away_penalty_p2 += 25;break;
                                            case 3: $away_penalty_p3 += 25;break;
                                            case 4: $away_penalty_ot += 25;break;
                                        }
                                        break;
                                }
                            } else {
                                $penalty = $penalty_time;
                                switch (getPeriod($playtime)) {
                                    case 1: $away_penalty_p1 += $penalty_time;break;
                                    case 2: $away_penalty_p2 += $penalty_time;break;
                                    case 3: $away_penalty_p3 += $penalty_time;break;
                                    case 4: $away_penalty_ot += $penalty_time;break;
                                }
                                switch ($penalty_extension) {
                                    case 0:
                                        $penalty .= ' Minuten';
                                        break;
                                    case 1:
                                        $penalty .= '+2 Minuten';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 2;break;
                                            case 2: $away_penalty_p2 += 2;break;
                                            case 3: $away_penalty_p3 += 2;break;
                                            case 4: $away_penalty_ot += 2;break;
                                        }
                                        break;
                                    case 2:
                                        $penalty .= '+10 Minuten Disziplinarstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 10;break;
                                            case 2: $away_penalty_p2 += 10;break;
                                            case 3: $away_penalty_p3 += 10;break;
                                            case 4: $away_penalty_ot += 10;break;
                                        }
                                        break;
                                    case 3:
                                        $penalty .= ' + Spieldauerstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 20;break;
                                            case 2: $away_penalty_p2 += 20;break;
                                            case 3: $away_penalty_p3 += 20;break;
                                            case 4: $away_penalty_ot += 20;break;
                                        }
                                        break;
                                    case 4:
                                        $penalty .= ' + Matchstrafe';
                                        switch (getPeriod($playtime)) {
                                            case 1: $away_penalty_p1 += 25;break;
                                            case 2: $away_penalty_p2 += 25;break;
                                            case 3: $away_penalty_p3 += 25;break;
                                            case 4: $away_penalty_ot += 25;break;
                                        }
                                        break;
                                }
                            }
                        }
                        
                        if ($info != '') $info = "<br><br>$info";
                        
                        $entryValues = array(
                            'playtime' => $playtime,
                            'result' => $homegoal . ":" . $awaygoal,
                            'player1' => $player1,
                            'team' => $teamname,
                            'penalty' => $penalty,
                            'reason' => $penalty_reason,
                            'info' => eregi_replace("\n", "<br>", $info),
                            'entry_time' => date('H:i', $entry_time)
                        );

                        $tickercontent = replaceFragmentPlaceholders($penaltyFragment, $entryValues) . $tickercontent;
                    } 
                }
            }
            
            switch (getPeriod($playtime)) {
                case 1: $period = "1.Drittel";break;
                case 2: $period = "2.Drittel";break;
                case 3: $period = "3.Drittel";break;
                case 4: $period = "Overtime";break;
            }            
            
            if ($running != "1") $period = "abgeschlossen";
            
            $matchValues = array(
                'home' => $home, 
                'homename' => $home_name,
                'away' => $away, 
                'awayname' => $away_name,
                'matchdate' => $matchdate, 
                'info' => $info, 
                'homegoal' => $homegoal, 
                'awaygoal' => $awaygoal,
                'period' => $period, 
                'playtime' => $playtime);
                
            $matchData = replaceFragmentPlaceholders($matchFragment, $matchValues);    
            
            $goalValues = array(
                'home_name' => $home_name,
                'away_name' => $away_name,
                'homegoal' => $homegoal,
                'home_goal_p1' => $home_goal_p1,
                'home_goal_p2' => $home_goal_p2,
                'home_goal_p3' => $home_goal_p3,
                'home_goal_ot' => $home_goal_ot,
                'awaygoal' => $awaygoal,
                'away_goal_p1' => $away_goal_p1,
                'away_goal_p2' => $away_goal_p2,
                'away_goal_p3' => $away_goal_p3,
                'away_goal_ot' => $away_goal_ot                
            );
            
            $goalStats = replaceFragmentPlaceholders($goalStatsFragment, $goalValues);
            
            
            $homepenalty = $home_penalty_p1 + $home_penalty_p2 + $home_penalty_p3 + $home_penalty_ot;
            $awaypenalty = $away_penalty_p1 + $away_penalty_p2 + $away_penalty_p3 + $away_penalty_ot;
            
            $penaltyValues = array(
                'home_name' => $home_name,
                'away_name' => $away_name,
                'homepenalty' => $homepenalty,
                'home_penalty_p1' => $home_penalty_p1,
                'home_penalty_p2' => $home_penalty_p2,
                'home_penalty_p3' => $home_penalty_p3,
                'home_penalty_ot' => $home_penalty_ot,
                'awaypenalty' => $awaypenalty,
                'away_penalty_p1' => $away_penalty_p1,
                'away_penalty_p2' => $away_penalty_p2,
                'away_penalty_p3' => $away_penalty_p3,
                'away_penalty_ot' => $away_penalty_ot                
            );
            
            $penaltyStats = replaceFragmentPlaceholders($penaltyStatsFragment, $penaltyValues);
            
            $meta = "";
            if ($running == "1") {
                $meta = $metaRefresh;
            }
            
            $bodyValues = array(
                'match' => $matchData,
                'entries' => $tickercontent,
                'goal_stats' => $goalStats,
                'penalty_stats' => $penaltyStats,
                'meta_refresh' => $meta
            );
            
            $content = replaceFragmentPlaceholders($bodyFragment, $bodyValues);
            
            // write the content to file
            writeContent($tickerFile, $content);
            
        } else {
            echo("Sorry pal, where'd you get this link from? There's no match!");
            exit();
        }
        
        
        
    } else {
        if (!file_exists($tickerFile)) {
            echo("Sorry pal, there's nothing to display for the given Ticker");
            exit();
        }
        $content = loadContent($tickerFile);
        
//        $file = fopen($tickerFile, "r");
//        $content = fread($file, filesize($tickerFile));
//        fclose($file);
    }

    // write the content
    echo $content;


    
    // replaces every occurrance of ${values.KEY} in $fragment with the 
    // value of ${values.KEY} 
    function replaceFragmentPlaceholders($fragment, $values) {
        $replacedContent = $fragment;
        $keys = array_keys($values);
        foreach ($keys as $key) {
            if (preg_match("/\@\{$key\}/", $replacedContent)) {
                $replacedContent = preg_replace("/\@\{$key\}/", $values[$key], $replacedContent);
            }
            
        }
        return $replacedContent;
    }
    
    function getPeriod($playtime) {
    
        list ($min, $sec) = split(":", $playtime);
        
        if ($min < 20) {
            return 1;
        } else if ($min < 40) {
            return 2;
        } else if ($min < 60  || ($min == 60 && $sec == 0)) {
            return 3;
        } else if (($min == 60 && $sec > 0) || ($min > 60)) {
            return 4;
        }    
    }
    
    function preparePlayer($player, $playerslist, $playerFragment, $playerLinkFragment) {
        if ($player == "") return "";
        for ($i = 0; $i < count($playerslist); $i++) {
            if (substr_count($playerslist[$i], $player) > 0) {
                // see if there's a link
                list($p, $l) = split(",", $playerslist[$i]);
                $playerVals = array(
                    'player' => $p,
                    'link' => $l
                );
                if (strlen(trim($l)) > 0) {
                    return replaceFragmentPlaceholders($playerLinkFragment, $playerVals);
                } else {
                    return replaceFragmentPlaceholders($playerFragment, $playerVals);
                }
            }
        }
        return $player;
    }
    
?>